#!/usr/bin/env bash

SOURCE="${BASH_SOURCE[0]}"
EXECUTABLE="RaygunAgent"
LOGFILE="RaygunAgent.log"

while [ -h "$SOURCE" ]; do
  DIR="$(cd -P "$(dirname "$SOURCE")" >/dev/null 2>&1 && pwd)"
  SOURCE="$(readlink "$SOURCE")"
  if [[ $SOURCE != /* ]]; then
    SOURCE="$DIR/$SOURCE"
  fi
done

DIR="$(cd -P "$(dirname "$SOURCE")" >/dev/null 2>&1 && pwd)"
BASEDIR=${DIR%/*}

if [ -d "$BASEDIR/runtime" ]; then
  RUNDIR=$BASEDIR/runtime
else
  echo "Cannot find $BASEDIR/runtime"
  echo "This folder is missing, or you do not have permission to run this program"
  exit 1
fi

if [ ! -x "$RUNDIR/$EXECUTABLE" ]; then
  echo "Cannot find $RUNDIR/$EXECUTABLE"
  echo "This file is missing, or you do not have permission to run this program"
  exit 1
fi

if [ ! -f "$BASEDIR/settings/agent-configuration.json" ]; then
  
  printf "It looks like there's no API key; enter it now. (ENTER to cancel) \n"
  read -r -p 'Enter ApiKey: ' apivar

  if [[ -z $apivar ]]; then
      echo "Exiting installation. No changes have been made."
      exit 0
  fi

  bash agent_controller.sh -register "${apivar}" &>/dev/null
fi

PIDFILE="raygunagent.pid"

if [ -f "$PIDFILE" ]; then
  PID=$(cat "$PIDFILE")
  checkpid=$(ps -ef | grep "$PID")
  if [ -z "$checkpid" ]; then
    echo "PID File found but PID not found. Removing PID file and continuing."
    rm "$PIDFILE"
  elif ! kill -0 "$PID" >/dev/null 2>&1; then
    echo "$PID not found. Removing PID file and continuing." >&2
  else
    echo "Raygun Agent already running on PID: $PID .. please stop before starting again."
    exit
  fi
fi

export Raygun_SettingsDirectoryPath=$BASEDIR/settings
export Raygun_BlacklistDirectoryPath=$BASEDIR/blacklist
export Raygun_LogDirectoryPath=$BASEDIR/agentlogs

echo "-- Starting Raygun Agent --"
nohup "$RUNDIR/$EXECUTABLE" > $LOGFILE & echo $! > "$PIDFILE"
echo "Raygun Agent started on PID: $!"
echo "-- Outputting Log: $LOGFILE"
echo "Use [ ps aux | grep Raygun ] to see running agent."
exit

