#!/usr/bin/env bash

set -e

SOURCE="${BASH_SOURCE[0]}"
EXECUTABLE="RaygunAgent"

while [ -h "$SOURCE" ]; do
  DIR="$(cd -P "$(dirname "$SOURCE")" >/dev/null 2>&1 && pwd)"
  SOURCE="$(readlink "$SOURCE")"
  if [[ $SOURCE != /* ]]; then
    SOURCE="$DIR/$SOURCE"
  fi
done

DIR="$(cd -P "$(dirname "$SOURCE")" >/dev/null 2>&1 && pwd)"
BASEDIR=${DIR%/*}

export Raygun_SettingsDirectoryPath=/$BASEDIR/settings
export Raygun_BlacklistDirectoryPath=$BASEDIR/blacklist
export Raygun_LogDirectoryPath=$BASEDIR/agentlogs

if [ -d "$BASEDIR/runtime" ]; then
  RUNDIR=$BASEDIR/runtime
else
  echo "Cannot find $BASEDIR/runtime"
  echo "This folder is missing, or you do not have permission to run this program"
  exit 1
fi

if [ ! -x "$RUNDIR/$EXECUTABLE" ]; then
  echo "Cannot find $RUNDIR/$EXECUTABLE"
  echo "This file is missing, or you do not have permission to run this program"
  exit 1
fi

PIDFILE="raygunagent.pid"

if [ -f "$PIDFILE" ]; then
  PID=$(cat "$PIDFILE")
  checkpid=$(ps -ef | grep "$PID")
  if [ -z "$checkpid" ]; then
    echo "PID File found but PID not found. Removing PID."
    rm "$PIDFILE"
  elif ! kill -0 "$PID" >/dev/null 2>&1; then
    echo "$PID not found. Removing PID file and continuing." >&2
  else
    kill -9 "$PID"
    echo "Raygun Agent found running on PID: $PID .. killing instance ..."
    if [ $? -gt 0 ]; then
      echo "Unable to stop $PID. Manual intervention required."
      exit 1
    fi
    echo "Instance stopped. Removing $PIDFILE"
    rm "$PIDFILE"
  fi
else
  echo "PID File not found, is the instance started? [ ps aux | grep Raygun ] to see running instances."
fi

exit

